==> cxf-testutils-2.0.6.14-fuse-sources.jar: org/apache/type_test/doc/TestRecSeqB6918.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.RecSeqB6918;


/**
 * <p>Java class for testRecSeqB6918 element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testRecSeqB6918">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}RecSeqB6918"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}RecSeqB6918"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testRecSeqB6918")
public class TestRecSeqB6918 {

    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected RecSeqB6918 x;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected RecSeqB6918 y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link RecSeqB6918 }
     *     
     */
    public RecSeqB6918 getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecSeqB6918 }
     *     
     */
    public void setX(RecSeqB6918 value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link RecSeqB6918 }
     *     
     */
    public RecSeqB6918 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecSeqB6918 }
     *     
     */
    public void setY(RecSeqB6918 value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.18-fuse-sources.jar: org/apache/type_test/doc/TestRecSeqB6918.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.RecSeqB6918;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}RecSeqB6918"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}RecSeqB6918"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testRecSeqB6918")
public class TestRecSeqB6918 {

    @XmlElement(required = true)
    protected RecSeqB6918 x;
    @XmlElement(required = true)
    protected RecSeqB6918 y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link RecSeqB6918 }
     *     
     */
    public RecSeqB6918 getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecSeqB6918 }
     *     
     */
    public void setX(RecSeqB6918 value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link RecSeqB6918 }
     *     
     */
    public RecSeqB6918 getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link RecSeqB6918 }
     *     
     */
    public void setY(RecSeqB6918 value) {
        this.y = value;
    }

}
